      subroutine mediaCount(cmp, ncmp, media, nmedia)
c       count number of different media in 'cmp' component 
      implicit none
#include "ZepDraw.h"
#include  "Zep3Vec.h"
#include  "Zcnfig.h"
      integer ncmp                ! input.  number of components in cmp
      record /Component/ cmp(ncmp)   ! input.  
      integer nmedia    ! output.  No. of different media used.
      character*8 media(*)    ! output.  media(i) (i=1, nmedia) is media id.


      integer i, j
      character*8 mat
c
c      if(NumComp .gt. 0) then
      if(ncmp .gt. 0) then
         nmedia = 1
         compnToMn(1) = 1
         media(1) = cmp(1).matter
c         do i = 2, NumComp
         do i = 2, ncmp
            mat = cmp(i).matter
            do j = 1, nmedia
               if(mat .eq. media(j)) then
                  compnToMn(i) =  j
                  goto 100
               endif
            enddo
            nmedia = nmedia + 1
            compnToMn(i) = nmedia
            media(nmedia) = mat
 100        continue
         enddo
      else
         nmedia = 0
      endif
      end
